tietools.group_leaves_in_tie_chain_by_immediate_parents
=======================================================

.. autofunction:: abjad.tools.tietools.group_leaves_in_tie_chain_by_immediate_parents.group_leaves_in_tie_chain_by_immediate_parents
